@@ -47,7 +47,7 @@ class File(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -71,7 +71,7 @@ class File(object):
 		The method to get the added_count
 
 		Returns:
-			int: A int value
+			int: An int representing the added_count
 		"""
 
 		return self.__added_count
@@ -95,7 +95,7 @@ class File(object):
 		The method to get the skipped_count
 
 		Returns:
-			int: A int value
+			int: An int representing the skipped_count
 		"""
 
 		return self.__skipped_count
@@ -119,7 +119,7 @@ class File(object):
 		The method to get the updated_count
 
 		Returns:
-			int: A int value
+			int: An int representing the updated_count
 		"""
 
 		return self.__updated_count
@@ -143,7 +143,7 @@ class File(object):
 		The method to get the total_count
 
 		Returns:
-			int: A int value
+			int: An int representing the total_count
 		"""
 
 		return self.__total_count
@@ -170,7 +170,7 @@ class File(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
